@@ -8,17 +8,14 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_lambda._jsii
-import aws_cdk.aws_s3._jsii
-import aws_cdk.core._jsii
-import aws_cdk.custom_resources._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@cloudcomponents/cdk-deletable-bucket",
-    "1.48.0",
+    "2.0.0",
     __name__[0:-6],
-    "cdk-deletable-bucket@1.48.0.jsii.tgz",
+    "cdk-deletable-bucket@2.0.0.jsii.tgz",
 )
 
 __all__ = [
